@@ -17,17 +17,21 @@ from core.managers.log_manager import logger
 from core.managers.auth_manager import auth_required, get_user_from_jwt
 from core.model import (
     acl_entry,
-    remote,
+    attribute,
+    bot,
+    bots_node,
+    collector,
+    collectors_node,
+    parameter,
+    presenter,
     presenters_node,
+    product_type,
+    publisher,
     publisher_preset,
     publishers_node,
-    bots_node,
-    bot_preset,
-    attribute,
-    collectors_node,
+    remote,
     organization,
     osint_source,
-    product_type,
     report_item_type,
     role,
     user,
@@ -304,6 +308,26 @@ class WordList(Resource):
         word_list.WordList.update(word_list_id, request.json)
 
 
+class Collectors(Resource):
+    def get(self):
+        search = request.args.get(key="search", default=None)
+        return collector.Collector.get_all_json(search)
+
+
+class Bots(Resource):
+    def get(self):
+        search = request.args.get(key="search", default=None)
+        return bot.Bot.get_all_json(search)
+
+    def put(self, bot_id):
+        return bot.Bot.update_bot_parameters(bot_id, request.json)
+
+
+class Parameters(Resource):
+    def get(self):
+        return parameter.Parameter.get_all_json()
+
+
 class CollectorsNodes(Resource):
     @auth_required("CONFIG_COLLECTORS_NODE_ACCESS")
     def get(self):
@@ -323,6 +347,13 @@ class CollectorsNodes(Resource):
         collectors_node.CollectorsNode.delete(node_id)
 
 
+class RefreshWorkers(Resource):
+    @auth_required("CONFIG_COLLECTORS_NODE_UPDATE")
+    def post(self):
+        collectors_manager.refresh_collectors()
+        bots_manager.refresh_bots()
+
+
 class OSINTSources(Resource):
     @auth_required("CONFIG_OSINT_SOURCE_ACCESS")
     def get(self):
@@ -335,6 +366,10 @@ class OSINTSources(Resource):
 
 
 class OSINTSource(Resource):
+    @auth_required("CONFIG_OSINT_SOURCE_ACCESS")
+    def get(self, source_id):
+        return osint_source.OSINTSource.get_by_id(source_id)
+
     @auth_required("CONFIG_OSINT_SOURCE_UPDATE")
     def put(self, source_id):
         updated_osint_source, default_group = collectors_manager.update_osint_source(source_id, request.json)
@@ -346,10 +381,20 @@ class OSINTSource(Resource):
         collectors_manager.delete_osint_source(source_id)
 
 
+class OSINTSourceRefresh(Resource):
+    @auth_required("CONFIG_OSINT_SOURCE_ACCESS")
+    def put(self, source_id):
+        result = collectors_manager.refresh_osint_source(source_id)
+        return result
+
+
 class OSINTSourcesExport(Resource):
     @auth_required("CONFIG_OSINT_SOURCE_ACCESS")
-    def post(self):
-        data = collectors_manager.export_osint_sources(request.json)
+    def get(self):
+        ids = request.args.getlist(key="ids")
+        data = collectors_manager.export_osint_sources(ids)
+        if data is None:
+            return "", 400
         return send_file(
             io.BytesIO(data),
             download_name="osint_sources_export.json",
@@ -362,8 +407,7 @@ class OSINTSourcesImport(Resource):
     @auth_required("CONFIG_OSINT_SOURCE_CREATE")
     def post(self):
         if file := request.files.get("file"):
-            collectors_node_id = request.form["collectors_node_id"]
-            collectors_manager.import_osint_sources(collectors_node_id, file)
+            collectors_manager.import_osint_sources(file)
 
 
 class OSINTSourceGroups(Resource):
@@ -445,6 +489,18 @@ class RemoteNodeConnect(Resource):
         return remote_manager.connect_to_node(remote_node_id)
 
 
+class Presenters(Resource):
+    def get(self):
+        search = request.args.get(key="search", default=None)
+        return presenter.Presenter.get_all_json(search)
+
+
+class Publishers(Resource):
+    def get(self):
+        search = request.args.get(key="search", default=None)
+        return publisher.Publisher.get_all_json(search)
+
+
 class PresentersNodes(Resource):
     @auth_required("CONFIG_PRESENTERS_NODE_ACCESS")
     def get(self):
@@ -538,27 +594,6 @@ class BotNodes(Resource):
         return bots_node.BotsNode.delete(node_id)
 
 
-class BotPresets(Resource):
-    @auth_required("CONFIG_BOT_PRESET_ACCESS")
-    def get(self):
-        search = request.args.get(key="search", default=None)
-        return bot_preset.BotPreset.get_all_json(search)
-
-    @auth_required("CONFIG_BOT_PRESET_CREATE")
-    def post(self):
-        bots_manager.add_bot_preset(request.json)
-
-
-class BotPreset(Resource):
-    @auth_required("CONFIG_BOT_PRESET_UPDATE")
-    def put(self, preset_id):
-        bot_preset.BotPreset.update(preset_id, request.json)
-
-    @auth_required("CONFIG_BOT_PRESET_DELETE")
-    def delete(self, preset_id):
-        return bot_preset.BotPreset.delete(preset_id)
-
-
 def initialize(api):
     api.add_resource(
         DictionariesReload,
@@ -598,8 +633,14 @@ def initialize(api):
     api.add_resource(WordList, "/api/v1/config/word-lists/<int:word_list_id>")
 
     api.add_resource(CollectorsNodes, "/api/v1/config/collectors-nodes", "/api/v1/config/collectors-nodes/<string:node_id>")
+    api.add_resource(RefreshWorkers, "/api/v1/config/workers/refresh")
+    api.add_resource(Collectors, "/api/v1/config/collectors", "/api/v1/config/collectors/<string:collector_type>")
+    api.add_resource(Bots, "/api/v1/config/bots", "/api/v1/config/bots/<string:bot_id>")
+    api.add_resource(Parameters, "/api/v1/config/parameters")
+
     api.add_resource(OSINTSources, "/api/v1/config/osint-sources")
     api.add_resource(OSINTSource, "/api/v1/config/osint-sources/<string:source_id>")
+    api.add_resource(OSINTSourceRefresh, "/api/v1/config/osint-sources/<string:source_id>/refresh")
     api.add_resource(OSINTSourcesExport, "/api/v1/config/export-osint-sources")
     api.add_resource(OSINTSourcesImport, "/api/v1/config/import-osint-sources")
     api.add_resource(OSINTSourceGroups, "/api/v1/config/osint-source-groups")
@@ -612,13 +653,13 @@ def initialize(api):
     api.add_resource(RemoteNode, "/api/v1/config/remote-nodes/<int:remote_node_id>")
     api.add_resource(RemoteNodeConnect, "/api/v1/config/remote-nodes/<int:remote_node_id>/connect")
 
+    api.add_resource(Presenters, "/api/v1/config/presenters")
+    api.add_resource(Publishers, "/api/v1/config/publishers")
     api.add_resource(PresentersNodes, "/api/v1/config/presenters-nodes", "/api/v1/config/presenters-nodes/<string:node_id>")
     api.add_resource(PublisherNodes, "/api/v1/config/publishers-nodes", "/api/v1/config/publishers-nodes/<string:node_id>")
     api.add_resource(PublisherPresets, "/api/v1/config/publishers-presets")
     api.add_resource(PublisherPreset, "/api/v1/config/publishers-presets/<string:preset_id>")
 
     api.add_resource(BotNodes, "/api/v1/config/bots-nodes", "/api/v1/config/bots-nodes/<string:node_id>")
-    api.add_resource(BotPresets, "/api/v1/config/bots-presets")
-    api.add_resource(BotPreset, "/api/v1/config/bots-presets/<string:preset_id>")
 
     api.add_resource(Nodes, "/api/v1/config/nodes", "/api/v1/config/nodes/<string:node_id>")
