@@ -27,8 +27,12 @@ def pre_seed(app):
         pre_seed_wordlists()
         logger.log_debug("Wordlists seeded")
 
+        pre_seed_workers()
+        logger.log_debug("Workers seeded")
+
     except Exception:
-        logger.log_debug_trace("Pre Seed failed")
+        logger.log_debug_trace()
+        logger.critical("Pre Seed failed")
 
 
 def pre_seed_source_groups():
@@ -37,6 +41,30 @@ def pre_seed_source_groups():
     OSINTSourceGroup.create(group_id="default", name="Default", description="Default group for uncategorized sources", default=True)
 
 
+def pre_seed_workers():
+    from core.managers.workers_pre_seed import collectors, parameters, bots, presenters, publishers
+    from core.model.collector import Collector
+    from core.model.parameter import Parameter
+    from core.model.presenter import Presenter
+    from core.model.publisher import Publisher
+    from core.model.bot import Bot
+
+    for p in parameters:
+        Parameter.add(p)
+
+    for c in collectors:
+        Collector.add(c)
+
+    for b in bots:
+        Bot.add(b)
+
+    for p in presenters:
+        Presenter.add(p)
+    
+    for p in publishers:
+        Publisher.add(p)
+
+
 def pre_seed_permissions():
     from core.model.permission import Permission
 
@@ -367,27 +395,6 @@ def pre_seed_permissions():
         "Delete bots node configuration",
     )
 
-    Permission.add(
-        "CONFIG_BOT_PRESET_ACCESS",
-        "Config bot presets access",
-        "Access to bot presets configuration",
-    )
-    Permission.add(
-        "CONFIG_BOT_PRESET_CREATE",
-        "Config bot preset create",
-        "Create bot preset configuration",
-    )
-    Permission.add(
-        "CONFIG_BOT_PRESET_UPDATE",
-        "Config bot preset update",
-        "Update bot preset configuration",
-    )
-    Permission.add(
-        "CONFIG_BOT_PRESET_DELETE",
-        "Config bot preset delete",
-        "Delete bot preset configuration",
-    )
-
     Permission.add(
         "CONFIG_PUBLISHERS_NODE_ACCESS",
         "Config publishers nodes access",
@@ -1262,14 +1269,8 @@ def pre_seed_wordlists():
                 "id": -1,
                 "name": "Default EN stop list",
                 "description": "English stop-word list packed with the standard Taranis NG installation.",
-                "categories": [
-                    {
-                        "name": "Default EN stop list",
-                        "description": "Source: https://www.maxqda.de/hilfe-mx20-dictio/stopp-listen",
-                        "entries": [],
-                        "link": "https://raw.githubusercontent.com/SK-CERT/Taranis-NG/main/resources/wordlists/en_complete.csv",
-                    }
-                ],
+                "link": "https://raw.githubusercontent.com/SK-CERT/Taranis-NG/main/resources/wordlists/en_complete.csv",
+                "entries": [],
                 "use_for_stop_words": True,
             }
         )
@@ -1280,14 +1281,8 @@ def pre_seed_wordlists():
                 "id": -1,
                 "name": "Default SK stop list",
                 "description": "Slovak stop-word list packed with the standard Taranis NG installation.",
-                "categories": [
-                    {
-                        "name": "Default SK stop list",
-                        "description": "Source: https://github.com/stopwords-iso/stopwords-sk/blob/master/stopwords-sk.txt",
-                        "entries": [],
-                        "link": "https://raw.githubusercontent.com/SK-CERT/Taranis-NG/main/resources/wordlists/sk_complete.csv",
-                    }
-                ],
+                "entries": [],
+                "link": "https://raw.githubusercontent.com/SK-CERT/Taranis-NG/main/resources/wordlists/sk_complete.csv",
                 "use_for_stop_words": True,
             }
         )
@@ -1298,14 +1293,8 @@ def pre_seed_wordlists():
                 "id": -1,
                 "name": "Default highlighting wordlist",
                 "description": "Default highlighting list packed with the standard Taranis NG installation.",
-                "categories": [
-                    {
-                        "name": "Default highlighting wordlist",
-                        "description": "Source: https://www.allot.com/100-plus-cybersecurity-terms-definitions/",
-                        "entries": [],
-                        "link": "https://raw.githubusercontent.com/SK-CERT/Taranis-NG/main/resources/wordlists/highlighting.csv",
-                    }
-                ],
+                "entries": [],
+                "link": "https://raw.githubusercontent.com/SK-CERT/Taranis-NG/main/resources/wordlists/highlighting.csv",
                 "use_for_stop_words": True,
             }
         )
