@@ -185,10 +185,15 @@ class NewsItemData(db.Model):
         return query
 
     @classmethod
-    def update_news_item_tags(cls, news_item_id, tags):
+    def update_news_item_tags(cls, news_item_aggregate_id, tags):
         try:
-            n_i_d = NewsItemData.get_news_item_data(news_item_id).first()
-            n_i_d.tags = tags
+            n_i_a = NewsItemAggregate.find(news_item_aggregate_id)
+            print(tags)
+            if (type(tags) is list):
+                for tag in tags:
+                    n_i_a.tags.append(NewsItemTag(name=tag, tag_type="undef"))
+            else:
+                n_i_a.tags.append(NewsItemTag(name=tags, tag_type="undef"))
             db.session.commit()
         except Exception:
             logger.log_debug_trace("Update News Item Tags Failed")
@@ -223,14 +228,6 @@ class NewsItemData(db.Model):
         return items, last_sync_time
 
 
-class NewsItemTag(db.Model):
-    id = db.Column(db.Integer, primary_key=True)
-    name = db.Column(db.String(255))
-    tag_type = db.Column(db.String(255))
-    n_i_d_id = db.Column(db.ForeignKey(NewsItemData.id), nullable=False)
-    n_i_d = db.relationship(NewsItemData, backref="tags")
-
-
 class NewsItem(db.Model):
     id = db.Column(db.Integer, primary_key=True)
 
@@ -566,6 +563,8 @@ class NewsItemAggregate(db.Model):
 
     comments = db.Column(db.String(), default="")
 
+    summary = db.Column(db.Text, default="")
+
     osint_source_group_id = db.Column(db.String, db.ForeignKey("osint_source_group.id"))
 
     news_items = db.relationship("NewsItem")
@@ -1052,6 +1051,15 @@ class NewsItemAggregate(db.Model):
                 if news_item.read is False:
                     aggregate.read = False
 
+    @classmethod
+    def update_news_items_aggregate_summary(cls, aggregate_id, summary):
+        try:
+            aggregate = cls.find(aggregate_id)
+            aggregate.summary = summary
+            db.session.commit()
+        except Exception:
+            logger.log_debug_trace(f"Update News Aggregate Summary Failed for {aggregate_id}")
+
     @classmethod
     def get_news_items_aggregate(cls, source_group, limit):
         if limit is not None:
@@ -1105,17 +1113,15 @@ class NewsItemAggregateSearchIndex(db.Model):
         data = aggregate.title
         data += f" {aggregate.description}"
         data += f" {aggregate.comments}"
+        data += f" {aggregate.summary}"
+        data += f" {aggregate.tags}"
 
         for news_item in aggregate.news_items:
-            data += " " + news_item.news_item_data.title
-            data += " " + news_item.news_item_data.review
-            data += " " + news_item.news_item_data.content
-            data += " " + news_item.news_item_data.author
-            data += " " + news_item.news_item_data.link
-
-            if news_item.news_item_data.tags is not None:
-                for tag in news_item.news_item_data.tags:
-                    data += f" {tag}"
+            data += f" {news_item.news_item_data.title}"
+            data += f" {news_item.news_item_data.review}"
+            data += f" {news_item.news_item_data.content}"
+            data += f" {news_item.news_item_data.author}"
+            data += f" {news_item.news_item_data.link}"
 
             for attribute in news_item.news_item_data.attributes:
                 data += f" {attribute.value}"
@@ -1176,3 +1182,20 @@ class ReportItemNewsItemAggregate(db.Model):
     @classmethod
     def count(cls, aggregate_id):
         return cls.query.filter_by(news_item_aggregate_id=aggregate_id).count()
+
+
+class NewsItemTag(db.Model):
+    id = db.Column(db.Integer, primary_key=True)
+    name = db.Column(db.String(255))
+    tag_type = db.Column(db.String(255))
+    n_i_a_id = db.Column(db.ForeignKey(NewsItemAggregate.id), nullable=False)
+    n_i_a = db.relationship(NewsItemAggregate, backref="tags")
+
+    def __init__(self, name, tag_type):
+        self.id = None
+        self.name = name
+        self.tag_type = tag_type
+
+    @classmethod
+    def find(cls, tag_id):
+        return cls.query.get(tag_id)
